@@ -346,7 +346,7 @@ class Table(_vtk.vtkTable, DataObject):
         """
         if arr is None:
             # use the first array in the row data
-            self.GetRowData().GetArrayName(0)
+            arr = self.GetRowData().GetArrayName(0)
         if isinstance(arr, str):
             arr = get_array(self, arr, preference=preference)
         # If array has no tuples return a NaN range
@@ -427,7 +427,16 @@ class Texture(_vtk.vtkTexture, DataObject):
 
     @property
     def n_components(self):
-        """Components in the image (e.g. 3 [or 4] for RGB[A])."""
+        """Components in the image (e.g. 3 [or 4] for RGB[A]).
+
+        Examples
+        --------
+        >>> from pyvista import examples
+        >>> texture = examples.download_masonry_texture()
+        >>> texture.n_components
+        3
+
+        """
         image = self.to_image()
         return image.active_scalars.shape[1]
 
@@ -456,7 +465,7 @@ class Texture(_vtk.vtkTexture, DataObject):
         Returns
         -------
         numpy.ndarray
-            Texture as a numpy array
+            Texture as a numpy array.
 
         """
         image = self.to_image()
@@ -468,10 +477,17 @@ class Texture(_vtk.vtkTexture, DataObject):
 
         return np.flip(image.active_scalars.reshape(shape, order='F'), axis=1).swapaxes(1, 0)
 
-    def plot(self, *args, **kwargs):
-        """Plot the texture as image data by itself."""
+    def plot(self, **kwargs):
+        """Plot the texture as image data by itself.
+
+        Parameters
+        ----------
+        **kwargs : dict, optional
+            Optional keyworld arguments. See :func:`pyvista.plot`.
+
+        """
         kwargs.setdefault("rgba", True)
-        return self.to_image().plot(*args, **kwargs)
+        return self.to_image().plot(**kwargs)
 
     @property
     def cube_map(self):
@@ -486,7 +502,6 @@ class Texture(_vtk.vtkTexture, DataObject):
 
     @cube_map.setter
     def cube_map(self, flag):
-        """Enable cube mapping if ``flag`` is True, disable it otherwise."""
         self.SetCubeMap(flag)
 
     def copy(self):
