@@ -1,7 +1,7 @@
-"""Examples routines."""
-
+"""Examples module."""
 from pyvista.examples.downloads import *
 from pyvista.examples.examples import *
+from . import planets
 from . import gltf
-from . import hdr
 from . import vrml
+from .cells import plot_cell
