@@ -1,22 +1,11 @@
-"""VRML examples."""
+"""vrml examples."""
 
-from .downloads import _retrieve_file
-
-VRML_SAMPLES_ROOT_URL = "https://raw.githubusercontent.com/lorensen/VTKExamples/master/"
-
-
-def _download_file(end_url):  # pragma: no cover
-    """Download a vrml example file."""
-    basename = end_url.split('/')[-1]
-    filename, _ = _retrieve_file(VRML_SAMPLES_ROOT_URL + end_url, basename)
-    return filename
+from .downloads import download_file
 
 
 def download_teapot():  # pragma: no cover
     """Download the a 2-manifold solid version of the famous teapot example.
 
-    Files hosted at https://github.com/lorensen/VTKExamples/blob/master/src/Testing/Data
-
     Returns
     -------
     str
@@ -32,14 +21,12 @@ def download_teapot():  # pragma: no cover
     >>> pl.show()
 
     """
-    return _download_file("src/Testing/Data/teapot.wrl")
+    return download_file("vrml/teapot.wrl")
 
 
 def download_sextant():  # pragma: no cover
     """Download the sextant example.
 
-    Files hosted at https://github.com/lorensen/VTKExamples/blob/master/src/Testing/Data
-
     Returns
     -------
     str
@@ -55,4 +42,4 @@ def download_sextant():  # pragma: no cover
     >>> pl.show()
 
     """
-    return _download_file("src/Testing/Data/sextant.wrl")
+    return download_file("vrml/sextant.wrl")
