@@ -1,6 +1,9 @@
 """Module containing pyvista implementation of vtkAxes."""
 from pyvista import _vtk
 
+from .actor import Actor
+from .axes_actor import AxesActor
+
 
 class Axes(_vtk.vtkAxes):
     """PyVista wrapper for the VTK Axes class.
@@ -31,20 +34,16 @@ class Axes(_vtk.vtkAxes):
     def __init__(self, show_actor=False, actor_scale=1, line_width=1.0, symmetric=False):
         """Initialize a new axes descriptor."""
         super().__init__()
-        self.mapper = None
-        self.actor = None
         self.SetSymmetric(symmetric)
-
         # Add the axes mapper
         self.mapper = _vtk.vtkPolyDataMapper()
         self.mapper.SetInputConnection(self.GetOutputPort())
         # Add the axes actor
-        self.actor = _vtk.vtkActor()
-        self.actor.SetMapper(self.mapper)
-        self.actor.SetVisibility(show_actor)
-        self.actor.SetScale(actor_scale)
-        prop = self.actor.GetProperty()
-        prop.SetLineWidth(line_width)
+        self.actor = Actor(mapper=self.mapper)
+        self.axes_actor = AxesActor()
+        self.actor.visibility = show_actor
+        self.actor.scale = actor_scale
+        self.actor.prop.line_width = line_width
 
     @property
     def origin(self):
@@ -80,7 +79,7 @@ class Axes(_vtk.vtkAxes):
         >>> axes = pv.Axes()
         >>> axes.show_actor()
         """
-        self.actor.VisibilityOn()
+        self.actor.visibility = True
 
     def hide_actor(self):
         """Hide an actor of axes.
@@ -91,7 +90,7 @@ class Axes(_vtk.vtkAxes):
         >>> axes = pv.Axes()
         >>> axes.hide_actor()
         """
-        self.actor.VisibilityOff()
+        self.actor.visibility = False
 
     def show_symmetric(self):
         """Show symmetric of axes.
@@ -114,3 +113,9 @@ class Axes(_vtk.vtkAxes):
         >>> axes.hide_symmetric()
         """
         self.SymmetricOff()
+
+    def __del__(self):
+        """Clean the attributes of the class."""
+        self.axes_actor = None
+        self.actor = None
+        self.mapper = None
