@@ -666,7 +666,6 @@ class CompositePolyDataMapper(_vtk.vtkCompositePolyDataMapper2, _BaseMapper):
         clim,
         cmap,
         flip_scalars,
-        categories,
         log_scale,
     ):
         """Set the scalars of the mapper.
@@ -720,7 +719,7 @@ class CompositePolyDataMapper(_vtk.vtkCompositePolyDataMapper2, _BaseMapper):
             (``clim``). This will automatically set the scalar bar
             ``below_label`` to ``'below'``.
 
-        clim : 2 item list
+        clim : Sequence
             Color bar range for scalars.  Defaults to minimum and
             maximum of scalars array.  Example: ``[-1, 2]``. ``rng``
             is also an accepted alias for this.
@@ -746,11 +745,6 @@ class CompositePolyDataMapper(_vtk.vtkCompositePolyDataMapper2, _BaseMapper):
             Flip direction of cmap. Most colormaps allow ``*_r``
             suffix to do this as well.
 
-        categories : bool
-            If set to ``True``, then the number of unique values in
-            the scalar array will be used as the ``n_colors``
-            argument.
-
         log_scale : bool
             Use log scale when mapping data to colors. Scalars less
             than zero are mapped to the smallest representable
