@@ -68,9 +68,9 @@ class PickingHelper:
 
         Parameters
         ----------
-        callback : function, optional
-            When input, calls this function after a selection is made. The
-            ``mesh`` is input as the first parameter to this function.
+        callback : callable, optional
+            When input, calls this callable after a selection is made. The
+            ``mesh`` is input as the first parameter to this callable.
 
         show : bool, optional
             Show the selection interactively. Best when combined with
@@ -260,10 +260,10 @@ class PickingHelper:
 
         Parameters
         ----------
-        callback : function, optional
-            When input, calls this function after a selection is made.
+        callback : callable, optional
+            When input, calls this callable after a selection is made.
             The picked_cells are input as the first parameter to this
-            function.
+            callable.
 
         through : bool, optional
             When ``True`` (default) the picker will select all cells
@@ -463,8 +463,8 @@ class PickingHelper:
         """Return the picked mesh.
 
         This returns the picked mesh after selecting a mesh with
-        :func:`<enable_mesh_picking> pyvista.Plotter.enable_mesh_picking` or
-        :func:`<enable_point_picking> pyvista.Plotter.enable_point_picking`.
+        :func:`enable_mesh_picking <pyvista.Plotter.enable_mesh_picking>` or
+        :func:`enable_point_picking <pyvista.Plotter.enable_point_picking>`.
 
         Returns
         -------
@@ -493,7 +493,7 @@ class PickingHelper:
         """Return the picked block index.
 
         This returns the picked block index after selecting a point with
-        :func:`<enable_point_picking> pyvista.Plotter.enable_point_picking`.
+        :func:`enable_point_picking <pyvista.Plotter.enable_point_picking>`.
 
         Returns
         -------
@@ -521,9 +521,9 @@ class PickingHelper:
 
         Parameters
         ----------
-        callback : function, optional
-            When input, calls this function after a selection is made. The
-            ``mesh`` is input as the first parameter to this function.
+        callback : callable, optional
+            When input, calls this callable after a selection is made. The
+            ``mesh`` is input as the first parameter to this callable.
 
         show_message : bool or str, optional
             Show the message about how to use the mesh picking tool. If this
@@ -570,7 +570,7 @@ class PickingHelper:
         Notes
         -----
         Picked point can be accessed from :attr:`picked_point
-        <PickingHelper.picked_point>` attribute.
+        <pyvista.Plotter.picked_point>` attribute.
 
         Examples
         --------
@@ -656,17 +656,17 @@ class PickingHelper:
         Enable picking a point at the mouse location in the render
         view using the ``P`` key. This point is saved to the
         ``.picked_point`` attribute on the plotter. Pass a callback
-        function that takes that point as an argument. The picked
+        that takes that point as an argument. The picked
         point can either be a point on the first intersecting mesh, or
         a point in the 3D window.
 
         Parameters
         ----------
         callback : callable, optional
-            When input, calls this function after a pick is made.  The
+            When input, calls this callable after a pick is made.  The
             picked point is input as the first parameter to this
-            function.  If ``use_mesh`` is ``True``, the callback
-            function will be passed a pointer to the picked mesh and
+            callable.  If ``use_mesh`` is ``True``, the callback
+            callable will be passed a pointer to the picked mesh and
             the point ID of the selected mesh.
 
         show_message : bool or str, optional
@@ -684,9 +684,8 @@ class PickingHelper:
             ``True``. Default 10.
 
         use_mesh : bool, optional
-            If ``True``, the callback function will be passed a
-            pointer to the picked mesh and the point ID of the
-            selected mesh.
+            If ``True``, the callback will be passed a pointer to the picked
+            mesh and the point ID of the selected mesh.
 
         show_point : bool, optional
             Show the picked point after clicking.
@@ -788,7 +787,7 @@ class PickingHelper:
         """Enable picking at paths.
 
         This is a convenience method for :func:`enable_point_picking
-        <PickingHelper.enable_point_picking>` to keep track of the
+        <pyvista.Plotter.enable_point_picking>` to keep track of the
         picked points and create a line using those points.
 
         The line is saved to the ``.picked_path`` attribute of this
@@ -797,9 +796,9 @@ class PickingHelper:
         Parameters
         ----------
         callback : callable, optional
-            When given, calls this function after a pick is made.  The
+            When given, calls this callable after a pick is made.  The
             entire picked path is passed as the only parameter to this
-            function.
+            callable.
 
         show_message : bool or str, optional
             Show the message about how to use the point picking
@@ -905,9 +904,9 @@ class PickingHelper:
         Parameters
         ----------
         callback : callable, optional
-            When given, calls this function after a pick is made.  The
+            When given, calls this callable after a pick is made.  The
             entire picked, geodesic path is passed as the only
-            parameter to this function.
+            parameter to this callable.
 
         show_message : bool or str, optional
             Show the message about how to use the point picking
@@ -1038,9 +1037,9 @@ class PickingHelper:
         Parameters
         ----------
         callback : callable, optional
-            When given, calls this function after a pick is made.  The
+            When given, calls this callable after a pick is made.  The
             entire picked path is passed as the only parameter to this
-            function.
+            callable.
 
         normal : tuple(float), optional
             The normal to the horizon surface's projection plane.
@@ -1129,7 +1128,7 @@ class PickingHelper:
         Parameters
         ----------
         callback : callable, optional
-            When input, this picker calls this function after a selection is
+            When input, this picker calls this callable after a selection is
             made. The composite index is passed to ``callback`` as the first
             argument and the dataset as the second argument.
 
@@ -1140,7 +1139,7 @@ class PickingHelper:
         Notes
         -----
         The picked block index can be accessed from :attr:`picked_block_index
-        <PickingHelper.picked_block_index>` attribute.
+        <pyvista.Plotter.picked_block_index>` attribute.
 
         Examples
         --------
@@ -1245,8 +1244,7 @@ class PickingHelper:
         Parameters
         ----------
         callback : callable
-            Callback function to call immediately after right
-            clicking.
+            Callback to call immediately after right clicking.
 
         """
 
