@@ -7,19 +7,20 @@ import warnings
 
 import numpy as np
 
+import pyvista
 from pyvista import _vtk
 
 
 def _set_plot_theme_from_env():
     """Set plot theme from an environment variable."""
-    from pyvista.themes import _ALLOWED_THEMES, set_plot_theme
+    from pyvista.themes import _NATIVE_THEMES, set_plot_theme
 
     if 'PYVISTA_PLOT_THEME' in os.environ:
         try:
             theme = os.environ['PYVISTA_PLOT_THEME']
             set_plot_theme(theme.lower())
-        except KeyError:
-            allowed = ', '.join([item.name for item in _ALLOWED_THEMES])
+        except ValueError:
+            allowed = ', '.join([item.name for item in _NATIVE_THEMES])
             warnings.warn(
                 f'\n\nInvalid PYVISTA_PLOT_THEME environment variable "{theme}". '
                 f'Should be one of the following: {allowed}'
@@ -55,18 +56,24 @@ def _get_vtk_id_type():
     return np.int32
 
 
-class PyvistaDeprecationWarning(Warning):
+class PyVistaDeprecationWarning(Warning):
     """Non-supressed Depreciation Warning."""
 
     pass
 
 
-class PyvistaFutureWarning(Warning):
+class PyVistaFutureWarning(Warning):
     """Non-supressed Future Warning."""
 
     pass
 
 
+class PyVistaEfficiencyWarning(Warning):
+    """Efficiency warning."""
+
+    pass
+
+
 def VTKVersionInfo():
     """Return the vtk version as a namedtuple."""
     version_info = namedtuple('VTKVersionInfo', ['major', 'minor', 'micro'])
@@ -145,3 +152,33 @@ def can_create_mpl_figure():  # pragma: no cover
 
 
 vtk_version_info = VTKVersionInfo()
+
+
+def set_pickle_format(format: str):
+    """Set the format used to serialize :class:`pyvista.DataObject` when pickled."""
+    supported = {'xml', 'legacy'}
+    format = format.lower()
+    if format not in supported:
+        raise ValueError(
+            f'Unsupported pickle format `{format}`. Valid options are `{"`, `".join(supported)}`.'
+        )
+    pyvista.PICKLE_FORMAT = format
+
+
+def no_new_attr(cls):
+    """Override __setattr__ to not permit new attributes."""
+    if not hasattr(cls, '_new_attr_exceptions'):
+        cls._new_attr_exceptions = []
+
+    def __setattr__(self, name, value):
+        """Do not allow setting attributes."""
+        if hasattr(self, name) or name in cls._new_attr_exceptions:
+            object.__setattr__(self, name, value)
+        else:
+            raise AttributeError(
+                f'Attribute "{name}" does not exist and cannot be added to type '
+                f'{self.__class__.__name__}'
+            )
+
+    setattr(cls, '__setattr__', __setattr__)
+    return cls
