@@ -16,12 +16,13 @@ def Spline(points, n_points=None):
 
     Parameters
     ----------
-    points : np.ndarray
+    points : numpy.ndarray
         Array of points to build a spline out of.  Array must be 3D
         and directionally ordered.
 
-    n_points : int, default: points.shape[0]
-        Number of points to interpolate along the points array.
+    n_points : int, optional
+        Number of points to interpolate along the points array. Defaults to
+        ``points.shape[0]``.
 
     Returns
     -------
